@@ -39,6 +39,32 @@
 #include "load-graph.h"
 
 
+
+
+void
+cb_kill_sigstop(GtkAction *action, gpointer data)
+{
+	ProcData * const procdata = data;
+
+	/* no confirmation */
+	kill_process (procdata, SIGSTOP);
+}
+
+
+
+
+void
+cb_kill_sigcont(GtkAction *action, gpointer data)
+{
+	ProcData * const procdata = data;
+
+	/* no confirmation */
+	kill_process (procdata, SIGCONT);
+}
+
+
+
+
 static void
 kill_process_helper(ProcData *procdata, int sig)
 {
@@ -183,16 +209,10 @@ cb_app_delete (GtkWidget *window, GdkEventAny *event, gpointer data)
 	ProcData * const procdata = data;
 
 	procman_save_config (procdata);
-	if (procdata->timeout != -1)
-		gtk_timeout_remove (procdata->timeout);
-	if (procdata->cpu_graph)
-		gtk_timeout_remove (procdata->cpu_graph->timer_index);
-	if (procdata->mem_graph)
-		gtk_timeout_remove (procdata->mem_graph->timer_index);
-	if (procdata->net_graph)
-		gtk_timeout_remove (procdata->net_graph->timer_index);
-	if (procdata->disk_timeout != -1)
-		gtk_timeout_remove (procdata->disk_timeout);
+	if (procdata->timeout)
+		g_source_remove (procdata->timeout);
+	if (procdata->disk_timeout)
+		g_source_remove (procdata->disk_timeout);
 
 	gtk_main_quit ();
 
@@ -355,9 +375,13 @@ cb_change_current_page (GtkNotebook *nb, gint num, gpointer data)
 
 	procdata->config.current_tab = num;
 
+
 	if (num == 0) {
-		if (procdata->timeout == -1)
-			procdata->timeout = gtk_timeout_add (
+
+		cb_timeout (procdata);
+
+		if (!procdata->timeout)
+			procdata->timeout = g_timeout_add (
 				procdata->config.update_interval,
 				cb_timeout, procdata);
 
@@ -365,27 +389,44 @@ cb_change_current_page (GtkNotebook *nb, gint num, gpointer data)
 			update_sensitivity (procdata, TRUE);
 	}
 	else {
-		if (procdata->timeout != -1 ) {
-			gtk_timeout_remove (procdata->timeout);
-			procdata->timeout = -1;
+		if (procdata->timeout) {
+			g_source_remove (procdata->timeout);
+			procdata->timeout = 0;
 		}
 
 		update_sensitivity (procdata, FALSE);
 	}
 
+
 	if (num == 1) {
 		load_graph_start (procdata->cpu_graph);
 		load_graph_start (procdata->mem_graph);
 		load_graph_start (procdata->net_graph);
-		load_graph_draw (procdata->cpu_graph);
-		load_graph_draw (procdata->mem_graph);
-		load_graph_draw (procdata->net_graph);
 	}
 	else {
 		load_graph_stop (procdata->cpu_graph);
 		load_graph_stop (procdata->mem_graph);
 		load_graph_stop (procdata->net_graph);
 	}
+
+
+	if (num == 2) {
+
+		cb_update_disks (procdata);
+
+		if(!procdata->disk_timeout) {
+			procdata->disk_timeout =
+				g_timeout_add (procdata->config.disks_update_interval,
+					       cb_update_disks,
+					       procdata);
+		}
+	}
+	else {
+		if(procdata->disk_timeout) {
+			g_source_remove (procdata->disk_timeout);
+			procdata->disk_timeout = 0;
+		}
+	}
 }
 
 
@@ -527,8 +568,6 @@ add_new_disks (gpointer key, gpointer value, gpointer data)
 gint
 cb_update_disks (gpointer data)
 {
-	static GStaticMutex mutex = G_STATIC_MUTEX_INIT;
-
 	ProcData * const procdata = data;
 
 	GtkTreeModel *model;
@@ -537,9 +576,6 @@ cb_update_disks (gpointer data)
 	GHashTable *new_disks = NULL;
 	guint i;
 
-	/* LOCK */
-	g_static_mutex_lock (&mutex);
-
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (procdata->disk_list));
 
 	entry = glibtop_get_mountlist (&mountlist, procdata->config.show_all_fs);
@@ -565,9 +601,6 @@ cb_update_disks (gpointer data)
 	g_hash_table_destroy (new_disks);
 	g_free (entry);
 
-	g_static_mutex_unlock (&mutex);
-	/* UNLOCK */
-
 	return TRUE;
 }
 
@@ -591,8 +624,9 @@ cb_timeout (gpointer data)
 
 	if(smooth_refresh_get(procdata->smooth_refresh, &new_interval))
 	{
-		procdata->timeout = gtk_timeout_add(new_interval,
-						    cb_timeout, procdata);
+		procdata->timeout = g_timeout_add(new_interval,
+						  cb_timeout,
+						  procdata);
 		return FALSE;
 	}
 
