@@ -76,13 +76,6 @@ struct _ProcConfig
 	gint 		num_cpus;
 };
 
-struct _PrettyTable {
-	GHashTable *app_hash;		/* apps gotten from libwnck */      
-	GHashTable *default_hash; 	/* defined in defaulttable.h */
-	gchar *datadir;
-};
-
-
 
 struct _ProcInfo
 {
